aboutsummaryrefslogtreecommitdiffstats
path: root/rust/src/api_wrappers.rs
diff options
context:
space:
mode:
Diffstat (limited to 'rust/src/api_wrappers.rs')
-rw-r--r--rust/src/api_wrappers.rs10
1 files changed, 5 insertions, 5 deletions
diff --git a/rust/src/api_wrappers.rs b/rust/src/api_wrappers.rs
index 4d3373e2..3f070593 100644
--- a/rust/src/api_wrappers.rs
+++ b/rust/src/api_wrappers.rs
@@ -6,15 +6,15 @@ use api_server::Server;
use database_models::EntityEditRow;
use diesel::Connection;
use errors::*;
-use fatcat_api::models;
-use fatcat_api::models::*;
-use fatcat_api::*;
+use fatcat_api_spec::models;
+use fatcat_api_spec::models::*;
+use fatcat_api_spec::*;
use futures::{self, Future};
use std::str::FromStr;
/// Helper for generating wrappers (which return "Box::new(futures::done(Ok(BLAH)))" like the
/// codegen fatcat-api code wants) that call through to actual helpers (which have simple Result<>
/// return types)
macro_rules! wrap_entity_handlers {
// Would much rather just have entity ident, then generate the other fields from that, but Rust
// stable doesn't have a mechanism to "concat" or generate new identifiers in macros, at least
@@ -6,15 +6,15 @@ use api_server::Server;
use std::str::FromStr;
/// Helper for generating wrappers (which return "Box::new(futures::done(Ok(BLAH)))" like the
-/// codegen fatcat-api code wants) that call through to actual helpers (which have simple Result<>
-/// return types)
+/// codegen fatcat-api-spec code wants) that call through to actual helpers (which have simple
+/// Result<> return types)
macro_rules! wrap_entity_handlers {
// Would much rather just have entity ident, then generate the other fields from that, but Rust